@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: get_audio.c,v 1.95 2004/01/10 10:38:53 takehiro Exp $ */
+/* $Id: get_audio.c,v 1.99 2004/02/26 17:20:51 takehiro Exp $ */
 
 
 #ifdef HAVE_CONFIG_H
@@ -1130,8 +1130,6 @@ parse_aiff_header(lame_global_flags * gfp, FILE * sf)
 
                 if (aiff_info.sampleSize == 16)
                   pcmswapbytes = (!swapbytes == (dataType == IFF_ID_2CLE));
-
-                fprintf(stderr, "swapbytes: %d\n", pcmswapbytes);
             }
             
             if (fskip(sf, (long) subSize, SEEK_CUR) != 0)
@@ -1381,20 +1379,20 @@ is_syncword_mp123(const void *const headerptr)
     if ((p[1] & 0x06) == 0x00)
         return 0;       /* no Layer I, II and III */
 #ifndef USE_LAYER_1
-    if ((p[1] & 0x06) == 0x03)
+    if ((p[1] & 0x06) == 0x03*2)
 	return 0; /* layer1 is not supported */
 #endif
 #ifndef USE_LAYER_2
-    if ((p[1] & 0x06) == 0x02)
+    if ((p[1] & 0x06) == 0x02*2)
 	return 0; /* layer1 is not supported */
 #endif
     if ((p[2] & 0xF0) == 0xF0)
         return 0;       /* bad bitrate */
     if ((p[2] & 0x0C) == 0x0C)
         return 0;       /* no sample frequency with (32,44.1,48)/(1,2,4)     */
-    if ((p[1] & 0x06) == 0x04) /* illegal Layer II bitrate/Channel Mode comb */
-        if (abl2[p[2] >> 4] & (1 << (p[3] >> 6)))
-            return 0;
+    if ((p[1] & 0x18) == 0x18 && (p[1] & 0x06) == 0x04
+	&& abl2[p[2] >> 4] & (1 << (p[3] >> 6)))
+	return 0;
     if ((p[3] & 3) == 2)
 	return 0;       /* reserved enphasis mode */
     return 1;
@@ -1457,7 +1455,7 @@ lame_decode_initfile(FILE * fd, mp3data_struct * mp3data)
             return -1;  /* failed */
     }
 
-    if ((buf[3] & 0xf0)==0) {
+    if ((buf[2] & 0xf0)==0) {
 	fprintf(stderr,"Input file is freeformat.\n");
 	freeformat = 1;
     }
