@@ -21,8 +21,11 @@
  */
 
 
-#include "get_audio.h"        
-#include <limits.h>
+#ifdef HAVE_LIMITS_H
+# include <limits.h>
+#endif
+
+#include "get_audio.h"
 
 #ifndef PATH_MAX
 #define PATH_MAX 1024
@@ -43,6 +46,7 @@ extern int enc_padding;           /* if decoder finds a Xing header */
 extern float update_interval;      /* to use Frank's time status display */
 extern int disable_wav_header;     /* for decoder only */
 extern mp3data_struct mp3input_data; /* used by MP3 */
+extern int print_clipping_info;      /* print info whether waveform clips */
 extern int in_signed;
 extern int in_unsigned;
 #define order_littleEndian 0
