@@ -1,4 +1,4 @@
-/* $Id: mp3x.c,v 1.16 2001/06/08 21:29:34 markt Exp $ */
+/* $Id: mp3x.c,v 1.18 2002/10/15 09:33:43 aleidinger Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -36,8 +36,8 @@ int main(int argc, char **argv)
 {
   char mp3buffer[LAME_MAXMP3BUFFER];
   lame_global_flags *gf;  
-  char outPath[MAX_NAME_SIZE];
-  char inPath[MAX_NAME_SIZE];
+  char outPath[PATH_MAX + 1];
+  char inPath[PATH_MAX + 1];
   int ret;
 
   gf=lame_init();
