@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: parse.c,v 1.193 2003/12/21 18:41:33 bouvigne Exp $ */
+/* $Id: parse.c,v 1.203 2004/03/23 03:07:43 olcios Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -51,6 +51,10 @@ char *strchr (), *strrchr ();
 #define PRTYD_MAXIMUM 31 
 #endif
 
+#ifdef HAVE_LIMITS_H
+# include <limits.h>
+#endif
+
 #include "lame.h"
 #include "set_get.h"
 
@@ -90,6 +94,7 @@ int enc_delay;
 int enc_padding;
 int disable_wav_header;
 mp3data_struct mp3input_data; /* used by MP3 */
+int print_clipping_info;      /* print info whether waveform clips */
 
 int in_signed=1;
 int in_unsigned=0;
@@ -257,15 +262,18 @@ int  print_license ( const lame_global_flags* gfp, FILE* const fp, const char* P
               "can include a compiled version of the LAME library (for example,\n"
               "lame.dll) with a commercial program.  Some notable requirements of\n"
               "the LGPL:\n"
-              "\n"
+              "\n" );
+    fprintf ( fp, 
               "1. In your program, you cannot include any source code from LAME, with\n"
               "   the exception of files whose only purpose is to describe the library\n"
               "   interface (such as lame.h).\n"
-              "\n"
+              "\n" );
+    fprintf ( fp, 
               "2. Any modifications of LAME must be released under the LGPL.\n"
               "   The LAME project (www.mp3dev.org) would appreciate being\n"
               "   notified of any modifications.\n"
-              "\n"
+              "\n" );
+    fprintf ( fp, 
               "3. You must give prominent notice that your program is:\n"
               "      A. using LAME (including version number)\n"
               "      B. LAME is under the LGPL\n"
@@ -274,11 +282,13 @@ int  print_license ( const lame_global_flags* gfp, FILE* const fp, const char* P
               "         source can be obtained (such as www.mp3dev.org)\n"
               "   An example of prominent notice would be an \"About the LAME encoding engine\"\n"
               "   button in some pull down menu within the executable of your program.\n"
-              "\n"
+              "\n" );
+    fprintf ( fp, 
               "4. If you determine that distribution of LAME requires a patent license,\n"
               "   you must obtain such license.\n"
               "\n"
-              "\n"
+              "\n" );
+    fprintf ( fp, 
               "*** IMPORTANT NOTE ***\n"
               "\n"
               "The decoding functions provided in LAME use the mpglib decoding engine which\n"
@@ -336,7 +346,8 @@ int  short_help ( const lame_global_flags* gfp, FILE* const fp, const char* Prog
               "\n"
               "RECOMMENDED:\n"
               "    lame -h input.wav output.mp3\n"
-              "\n"
+              "\n", ProgramName );
+    fprintf ( fp, 
               "OPTIONS:\n"
               "    -b bitrate      set the bitrate, default 128 kbps\n"
               "    -f              fast mode (lower quality)\n"
@@ -344,13 +355,15 @@ int  short_help ( const lame_global_flags* gfp, FILE* const fp, const char* Prog
               "    -m mode         (s)tereo, (j)oint, (m)ono\n"
               "                    default is (j) or (s) depending on bitrate\n"
               "    -V n            quality setting for VBR.  default n=%i\n"
-              "\n"
+              "\n", lame_get_VBR_q(gfp) );
+    fprintf ( fp, 
               "    --preset type   type must be \"medium\", \"standard\", \"extreme\", \"insane\",\n"
               "                    or a value for an average desired bitrate and depending\n"                       
               "                    on the value specified, appropriate quality settings will\n"
               "                    be used.\n"
               "                    \"--preset help\" gives more info on these\n"
-              "\n"
+              "\n" );
+    fprintf ( fp, 
 #if defined(WIN32)
               "    --priority type  sets the process priority\n"
               "                     0,1 = Low priority\n"
@@ -368,8 +381,7 @@ int  short_help ( const lame_global_flags* gfp, FILE* const fp, const char* Prog
               "\n"
 #endif
               "    --longhelp      full list of options\n"
-              "\n",
-              ProgramName, lame_get_VBR_q(gfp) );
+              "\n" );
  
     return 0;
 }
@@ -403,7 +415,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "\n"
               "RECOMMENDED:\n"
               "    lame -h input.wav output.mp3\n"
-              "\n"
+              "\n", ProgramName );
+    fprintf ( fp,
               "OPTIONS:\n"
               "  Input options:\n"
               "    -r              input is raw pcm\n"
@@ -416,6 +429,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "    --little-endian input is little-endian (default from host)\n"
               "    --big-endian    input is big-endian (default from host)\n"
 #endif
+               );
+    fprintf ( fp,
               "    --mp1input      input file is a MPEG Layer I   file\n"
               "    --mp2input      input file is a MPEG Layer II  file\n"
               "    --mp3input      input file is a MPEG Layer III file\n"
@@ -424,7 +439,7 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
  	      "    --nogapout <dir>\n"
  	      "                    output dir for gapless encoding (must precede --nogap)\n"
  	      "    --nogaptags     allow the use of VBR tags in gapless encoding"
-              , ProgramName );
+               );
 
     wait_for ( fp, lessmode );
     fprintf ( fp,
@@ -436,15 +451,25 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "    --freeformat    produce a free format bitstream\n"
               "    --decode        input=mp3 file, output=wav\n"
               "    -t              disable writing wav header when using --decode\n"
+              );
+    fprintf ( fp,
               "    --comp  <arg>   choose bitrate to achive a compression ratio of <arg>\n"
               "    --scale <arg>   scale input (multiply PCM data) by <arg>\n"
               "    --scale-l <arg> scale channel 0 (left) input (multiply PCM data) by <arg>\n"
               "    --scale-r <arg> scale channel 1 (right) input (multiply PCM data) by <arg>\n"
+              );
+    fprintf ( fp,
+              "    --replaygain-fast   compute RG fast but slightly inaccurately (default)\n"
 #ifdef DECODE_ON_THE_FLY
-              "    --replaygain-accurate  slightly more accurate and much slower ReplayGain\n"
-              "    --clipdetect    determine whether clipping occurs and display an appropriate\n"
-              "                    message. store the MP3 peak sample in LAME Tag\n"
+              "    --replaygain-accurate   compute RG more accurately and find the peak sample\n"
 #endif
+              "    --noreplaygain  disable ReplayGain analysis\n"
+#ifdef DECODE_ON_THE_FLY
+              "    --clipdetect    enable --replaygain-accurate and print a message whether\n"
+              "                    clipping occurs and how far the waveform is from full scale\n"
+#endif
+              );
+    fprintf ( fp,
               "    --preset type   type must be \"medium\", \"standard\", \"extreme\", \"insane\",\n"
               "                    or a value for an average desired bitrate and depending\n"                       
               "                    on the value specified, appropriate quality settings will\n"
@@ -462,7 +487,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "    --quiet         don't print anything on screen\n"
               "    --brief         print more useful information\n"
               "    --verbose       print a lot of useful information\n"
-              "\n"
+              "\n" );
+    fprintf ( fp,
               "  Noise shaping & psycho acoustic algorithms:\n"
               "    -q <arg>        <arg> = 0...9.  Default  -q 5 \n"
               "                    -q 0:  Highest quality, very slow \n"
@@ -479,20 +505,23 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "\n"
               "  ABR options:\n"
               "    --abr <bitrate> specify average bitrate desired (instead of quality)\n"
-              "\n"
+              "\n" );
+    fprintf ( fp,
               "  VBR options:\n"
               "    -v              use variable bitrate (VBR) (--vbr-old)\n"
               "    --vbr-old       use old variable bitrate (VBR) routine\n"
               "    --vbr-new       use new variable bitrate (VBR) routine\n"
               "    -V n            quality setting for VBR.  default n=%i\n"
               "                    0=high quality,bigger files. 9=smaller files\n"
+              , lame_get_VBR_q(gfp) );
+    fprintf ( fp,
               "    -b <bitrate>    specify minimum allowed bitrate, default  32 kbps\n"
               "    -B <bitrate>    specify maximum allowed bitrate, default 320 kbps\n"
               "    -F              strictly enforce the -b option, for use with players that\n"
               "                    do not support low bitrate mp3\n"
               "    -t              disable writing LAME Tag\n"
               "    -T              enable and force writing LAME Tag\n"
-              , lame_get_VBR_q(gfp) );
+              );
   
     wait_for ( fp, lessmode );  
     fprintf ( fp,
@@ -502,10 +531,13 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "    --athonly       ignore GPSYCHO completely, use ATH only\n"
               "    --athtype n     selects between different ATH types [0-4]\n"
               "    --athlower x    lowers ATH by x dB\n"
+              );
+    fprintf ( fp,
               "    --athaa-type n  ATH auto adjust types 1-3, else no adjustment\n"
               "    --athaa-loudapprox n   n=1 total energy or n=2 equal loudness curve\n"
               "    --athaa-sensitivity x  activation offset in -/+ dB for ATH auto-adjustment\n" 
-              "\n"
+              "\n" );
+    fprintf ( fp,
               "  PSY related:\n"
               "    --short         use short blocks when appropriate\n"
               "    --noshort       do not use short blocks\n"
@@ -515,6 +547,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
 /* this is redundant, we already have --notemp */
               "    --temporal-masking n  use temporal masking effect n=0:no n=1:yes\n"
 #endif
+            );
+    fprintf ( fp,
               "    --notemp        disable temporal masking effect\n"
               "    --nssafejoint   M/S switching criterion\n"
               "    --nsmsfix <arg> M/S switching tuning [effective 0-3.5]\n"
@@ -522,6 +556,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "    --ns-bass x     adjust masking for sfbs  0 -  6 (long)  0 -  5 (short)\n"
               "    --ns-alto x     adjust masking for sfbs  7 - 13 (long)  6 - 10 (short)\n"         
               "    --ns-treble x   adjust masking for sfbs 14 - 21 (long) 11 - 12 (short)\n"
+            );
+    fprintf ( fp,
               "    --ns-sfb21 x    change ns-treble by x dB for sfb21\n"
               "    --shortthreshold x,y  short block switching threshold, x for L/R/M channel, y for S channel\n"
               "  Noise Shaping related:\n"
@@ -550,7 +586,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "                    (the checksum is computed correctly)\n"
               "    --nores         disable the bit reservoir\n"
               "    --strictly-enforce-ISO   comply as much as possible to ISO MPEG spec\n"
-              "\n"
+              "\n" );
+    fprintf ( fp,
               "  Filter options:\n"
               "    -k              keep ALL frequencies (disables all filters),\n"
               "                    Can cause ringing and twinkling\n"
@@ -558,6 +595,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "  --lowpass-width <freq>  frequency(kHz) - default 15%% of lowpass freq\n"
               "  --highpass <freq>       frequency(kHz), highpass filter cutoff below freq\n"
               "  --highpass-width <freq> frequency(kHz) - default 15%% of highpass freq\n"
+            );
+    fprintf ( fp,
               "  --resample <sfreq>  sampling frequency of output file(kHz)- default=automatic\n"
                );
   
@@ -571,6 +610,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "    --tc <comment>  user-defined text (max 30 chars for v1 tag, 28 for v1.1)\n"
               "    --tn <track>    audio/song track number (1 to 255, creates v1.1 tag)\n"
               "    --tg <genre>    audio/song genre (name or number in list)\n"
+              );
+    fprintf ( fp,
               "    --add-id3v2     force addition of version 2 tag\n"
               "    --id3v1-only    add only a version 1 tag\n"
               "    --id3v2-only    add only a version 2 tag\n"
@@ -578,7 +619,8 @@ int  long_help ( const lame_global_flags* gfp, FILE* const fp, const char* Progr
               "    --pad-id3v2     pad version 2 tag with extra 128 bytes\n"
               "    --genre-list    print alphabetically sorted ID3 genre list and exit\n"
               "    --ignore-tag-errors  ignore errors in values passed for tags\n"
-              "\n"
+              "\n" );
+    fprintf ( fp,
               "    Note: A version 2 tag will NOT be added unless one of the input fields\n"
               "    won't fit in a version 1 tag (e.g. the title string is longer than 30\n"
               "    characters), or the '--add-id3v2' or '--id3v2-only' options are used,\n"
@@ -675,14 +717,20 @@ static void  presets_longinfo_dm ( FILE* msgfp )
         "They have for the most part been subject to and tuned via rigorous double blind\n"
         "listening tests to verify and achieve this objective.\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "These are continually updated to coincide with the latest developments that\n"
         "occur and as a result should provide you with nearly the best quality\n"
         "currently possible from LAME.\n"
-        "\n"
+        "\n" 
+        );
+        fprintf ( msgfp,
         "To activate these presets:\n"
         "\n"
         "   For VBR modes (generally highest quality):\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "     \"--preset medium\" This preset should provide near transparency\n"
         "                             to most people on most music.\n"
         "\n"
@@ -690,11 +738,15 @@ static void  presets_longinfo_dm ( FILE* msgfp )
         "                             to most people on most music and is already\n"
         "                             quite high in quality.\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "     \"--preset extreme\" If you have extremely good hearing and similar\n"
         "                             equipment, this preset will generally provide\n"
         "                             slightly higher quality than the \"standard\"\n"
         "                             mode.\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "   For CBR 320kbps (highest quality possible from the --preset switches):\n"
         "\n"
         "     \"--preset insane\"  This preset will usually be overkill for most\n"
@@ -702,16 +754,22 @@ static void  presets_longinfo_dm ( FILE* msgfp )
         "                             have the absolute highest quality with no\n"
         "                             regard to filesize, this is the way to go.\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "   For ABR modes (high quality per given bitrate but not as high as VBR):\n"
         "\n"
         "     \"--preset <kbps>\"  Using this preset will usually give you good\n"
         "                             quality at a specified bitrate. Depending on the\n"
         "                             bitrate entered, this preset will determine the\n"
+        );
+        fprintf ( msgfp,
         "                             optimal settings for that particular situation.\n"
         "                             While this approach works, it is not nearly as\n"
         "                             flexible as VBR, and usually will not attain the\n"
         "                             same level of quality as VBR at higher bitrates.\n"  
         "\n"
+        );
+        fprintf ( msgfp,
         "The following options are also available for the corresponding profiles:\n"
         "\n"
         "   <fast>        standard\n"
@@ -722,11 +780,15 @@ static void  presets_longinfo_dm ( FILE* msgfp )
         "                      \"--preset 185\" activates this\n"
         "                      preset and uses 185 as an average kbps.\n" 
         "\n"
+        );
+        fprintf ( msgfp,
         "   \"fast\" - Enables the new fast VBR for a particular profile. The\n"
         "            disadvantage to the speed switch is that often times the\n"
         "            bitrate will be slightly higher than with the normal mode\n"
         "            and quality may be slightly lower also.\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "   \"cbr\"  - If you use the ABR mode (read above) with a significant\n"
         "            bitrate such as 80, 96, 112, 128, 160, 192, 224, 256, 320,\n"
         "            you can use the \"cbr\" option to force CBR mode encoding\n"
@@ -734,6 +796,8 @@ static void  presets_longinfo_dm ( FILE* msgfp )
         "            quality but CBR may be useful in situations such as when\n"
         "            streaming an mp3 over the internet may be important.\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "    For example:\n"
         "\n"
         "    \"--preset fast standard <input file> <output file>\"\n"
@@ -742,6 +806,8 @@ static void  presets_longinfo_dm ( FILE* msgfp )
         " or \"--preset extreme <input file> <output file>\"\n"
         "\n"
         "\n"
+        );
+        fprintf ( msgfp,
         "A few aliases are available for ABR mode:\n"
         "phone => 16kbps/mono        phon+/lw/mw-eu/sw => 24kbps/mono\n"
         "mw-us => 40kbps/mono        voice => 56kbps/mono\n"
@@ -887,6 +953,8 @@ static int  presets_set( lame_t gfp, int fast, int cbr, const char* preset_name,
                    "                             \"--preset 185\" activates this\n"
                    "                             preset and uses 185 as an average kbps.\n" 
                    "\n"
+        );
+        fprintf ( stderr,
                    "    Some examples:\n"
                    "\n"
                    " or \"%s --preset fast standard <input file> <output file>\"\n"
@@ -941,6 +1009,7 @@ static int local_strcasecmp ( const char* s1, const char* s2 )
 }
 
 
+
 /* LAME is a simple frontend which just uses the file extension */
 /* to determine the file type.  Trying to analyze the file */
 /* contents is well beyond the scope of LAME and should not be added. */
@@ -1001,6 +1070,7 @@ char* const inPath, char* const outPath, char **nogap_inPath, int *num_nogap)
     int         nogap_tags=0;  /* set to 1 to use VBR tags in NOGAP mode */
     const char* ProgramName  = argv[0]; 
     int count_nogap=0;
+    int 	noreplaygain=0;  /* is RG explicitly disabled by the user */
 
     inPath [0] = '\0';   
     outPath[0] = '\0';
@@ -1012,6 +1082,7 @@ char* const inPath, char* const outPath, char **nogap_inPath, int *num_nogap)
     enc_delay=-1;
     mp3_delay = 0;   
     mp3_delay_set=0;
+    print_clipping_info = 0;
     disable_wav_header=0;
     id3tag_init (gfp);
 
@@ -1265,12 +1336,24 @@ char* const inPath, char* const outPath, char **nogap_inPath, int *num_nogap)
                 T_ELIF ("freeformat")
                     lame_set_free_format(gfp,1);
 
+                T_ELIF ("replaygain-fast")
+                    lame_set_findReplayGain(gfp,1);
+		    
 #ifdef DECODE_ON_THE_FLY
                 T_ELIF ("replaygain-accurate")
-                    lame_set_ReplayGain_decode(gfp,1);
+                    lame_set_decode_on_the_fly(gfp,1);
+                    lame_set_findReplayGain(gfp,1);
+#endif
 
+                T_ELIF ("noreplaygain")
+		    noreplaygain = 1;
+                    lame_set_findReplayGain(gfp,0);
+		    
+
+#ifdef DECODE_ON_THE_FLY
                 T_ELIF ("clipdetect")
-                    lame_set_findPeakSample(gfp,1);
+   		    print_clipping_info = 1;
+		    lame_set_decode_on_the_fly(gfp,1);
 #endif
 
                 T_ELIF ("athshort")
@@ -1279,15 +1362,18 @@ char* const inPath, char* const outPath, char **nogap_inPath, int *num_nogap)
                 T_ELIF ("nohist")
                     brhist = 0;
                 
-#if defined(__OS2__)
+#if defined(__OS2__) || defined(WIN32)
       		T_ELIF ("priority")
-      		    argUsed=1;
-      		    setOS2Priority(gfp, atoi(nextArg));
-#endif
-#if defined(WIN32)
-      		T_ELIF ("priority")
-      		    argUsed=1;
-      		    setWin32Priority(gfp, atoi(nextArg));
+                    char *endptr;
+                    int priority = (int)strtol(nextArg, &endptr, 10);
+                    if (endptr != nextArg) {
+                        argUsed=1;
+                    }
+# if defined(__OS2__)
+                    setOS2Priority(gfp, priority);
+# else /* WIN32 */
+                    setWin32Priority(gfp, priority);
+# endif
 #endif
 
                 /* options for ID3 tag */
@@ -1820,6 +1906,10 @@ char* const inPath, char* const outPath, char **nogap_inPath, int *num_nogap)
         }
     }
     
+    /* RG is enabled by default */
+    if (!noreplaygain) 
+      lame_set_findReplayGain(gfp,1);
+    
     /* disable VBR tags with nogap unless the VBR tags are forced */
     if (nogap && lame_get_bWriteVbrTag(gfp) && nogap_tags==0) {
       fprintf(stderr,"Note: Disabling VBR Xing/Info tag since it interferes with --nogap\n");
@@ -1844,11 +1934,25 @@ char* const inPath, char* const outPath, char **nogap_inPath, int *num_nogap)
     }
 #endif
 
-#ifdef DECODE_ON_THE_FLY
+
     if (( input_format == sf_mp1 ||
           input_format == sf_mp2 ||
           input_format == sf_mp3) && 
-	  lame_get_ReplayGain_decode( gfp ) ){
+	  print_clipping_info ){
+
+        fprintf(stderr, "\nError: input cannot be MPEG when --clipdetect is used\n"
+	    	        "\n--clipdetect requires decoding of MPEG *output* on the fly which\n"
+			"cannot be performed simultaneously with decoding MPEG *input*.\n"
+			"\nUse a plain .wav file as input with --clipdetect.\n");
+
+	return -1;
+    }
+
+    
+    if (( input_format == sf_mp1 ||
+          input_format == sf_mp2 ||
+          input_format == sf_mp3) && 
+	  lame_get_decode_on_the_fly( gfp ) ){
 
         fprintf(stderr, "\nError: input cannot be MPEG when --replaygain-accurate is used\n"
 	    	        "\n--replaygain-accurate requires decoding of MPEG *output* on the fly which\n"
@@ -1858,19 +1962,6 @@ char* const inPath, char* const outPath, char **nogap_inPath, int *num_nogap)
 	return -1;
     }
 
-    if (( input_format == sf_mp1 ||
-          input_format == sf_mp2 ||
-          input_format == sf_mp3) && 
-	  lame_get_findPeakSample( gfp ) ){
-
-        fprintf(stderr, "\nError: input cannot be MPEG when --clipdetect is used\n"
-	    	        "\n--clipdetect requires decoding of MPEG *output* on the fly which\n"
-			"cannot be performed simultaneously with decoding MPEG *input*.\n"
-			"\nUse a plain .wav file as input with --clipdetect.\n");
-
-	return -1;
-    }
-#endif
     
     if ( input_format == sf_ogg ) {
         fprintf(stderr, "sorry, vorbis support in LAME is deprecated.\n");
