@@ -23,7 +23,9 @@
 #define LAME_BITSTREAM_H
 #include "util.h"
 
-int format_bitstream(lame_global_flags *gfp, int bitsPerFrame);
+int getframebits(const lame_global_flags *gfp);
+
+int format_bitstream(lame_global_flags *gfp);
 
 void flush_bitstream(lame_global_flags *gfp);
 void add_dummy_byte ( lame_global_flags* const gfp, unsigned char val );
@@ -35,3 +37,4 @@ int compute_flushbits(const lame_global_flags *gfp, int *nbytes);
 
 
 #endif
+
