@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: lame.c,v 1.261 2004/03/23 01:57:17 olcios Exp $ */
+/* $Id: lame.c,v 1.261.2.1 2004/06/26 17:08:07 robert Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -1095,8 +1095,8 @@ lame_init_params(lame_global_flags * const gfp)
      * Robert Hegemann 2000-06-22
      */
     gfc->slot_lag = gfc->frac_SpF = 0;
-    if (gfp->VBR == vbr_off && !gfp->disable_reservoir)
-	gfc->slot_lag = gfc->frac_SpF
+    if (gfp->VBR == vbr_off)
+        gfc->slot_lag = gfc->frac_SpF
 	    = ((gfp->version+1)*72000L*gfp->brate) % gfp->out_samplerate;
 
     /* mid side sparsing */
