@@ -49,30 +49,31 @@ int apply_abr_preset(lame_global_flags*  gfp, int preset, int enforce)
         FLOAT  scale;
         FLOAT  ath_curve;
         FLOAT  interch;
+        int sfscale;
     } abr_presets_t;
 
 
 
     /* Switch mappings for ABR mode */
     const abr_presets_t abr_switch_map [] = {
-        /* kbps  quant q_s safejoint nsmsfix st_lrm  st_s  ns-bass scale ath4_curve, interch */
-        {   8,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0012 }, /*   8, impossible to use in stereo */
-        {  16,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0010 }, /*  16 */
-        {  24,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0010 }, /*  24 */
-        {  32,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0010 }, /*  32 */
-        {  40,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0009 }, /*  40 */
-        {  48,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0009 }, /*  48 */
-        {  56,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0008 }, /*  56 */
-        {  64,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        11,  0.0008 }, /*  64 */
-        {  80,   1,    0,  0,        0   ,    4.50, 30   ,  0,      0.95,        10,  0.0007 }, /*  80 */
-        {  96,   1,    0,  0,        0   ,    4.50, 30   , -2,      0.95,         8,  0.0006 }, /*  96 */
-        { 112,   1,    0,  0,        0   ,    4.50, 30   , -4,      0.95,         7,  0.0005 }, /* 112 */
-        { 128,   1,    0,  0,        0   ,    4.40, 25   , -6,      0.95,         5,  0.0002 }, /* 128 */
-        { 160,   1,    0,  1,        1.64,    4.25, 15   , -4,      0.95,         4,  0      }, /* 160 */
-        { 192,   1,    0,  1,        1.38,    3.50, 15   , -2,      0.97,         3,  0      }, /* 192 */
-        { 224,   3,    0,  1,        1.10,    3.20, 15   ,  0,      0.98,         2,  0      }, /* 224 */
-        { 256,   3,    3,  1,        0.85,    3.10, 15   ,  0,      1.00,         1,  0      }, /* 256 */
-        { 320,   3,    3,  1,        0.6 ,    3.00, 15   ,  0,      1.00,         0,  0      }  /* 320 */
+        /* kbps  quant q_s safejoint nsmsfix st_lrm  st_s  ns-bass scale ath4_curve, interch , sfscale */
+        {   8,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0012 ,       1}, /*   8, impossible to use in stereo */
+        {  16,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0010 ,       1}, /*  16 */
+        {  24,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0010 ,       1}, /*  24 */
+        {  32,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0010 ,       1}, /*  32 */
+        {  40,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0009 ,       1}, /*  40 */
+        {  48,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0009 ,       1}, /*  48 */
+        {  56,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0008 ,       1}, /*  56 */
+        {  64,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        11,  0.0008 ,       1}, /*  64 */
+        {  80,   9,    9,  0,        0   ,    6.20, 45   ,  0,      0.95,        10,  0.0007 ,       1}, /*  80 */
+        {  96,   9,    9,  0,        0   ,    6.20, 45   , -2,      0.95,         8,  0.0006 ,       1}, /*  96 */
+        { 112,   9,    9,  0,        0   ,    6.20, 45   , -4,      0.95,         7,  0.0005 ,       1}, /* 112 */
+        { 128,   9,    9,  0,        0   ,    5.90, 40   , -6,      0.95,         5,  0.0002 ,       1}, /* 128 */
+        { 160,   9,    9,  1,        1.64,    5.00, 35   , -4,      0.95,         4,  0      ,       1}, /* 160 */
+        { 192,   9,    9,  1,        1.38,    4.30, 25   , -2,      0.97,         3,  0      ,       0}, /* 192 */
+        { 224,   9,    9,  1,        1.10,    4.20, 25   ,  0,      0.98,         2,  0      ,       0}, /* 224 */
+        { 256,   9,    9,  1,        0.85,    4.20, 25   ,  0,      1.00,         1,  0      ,       0}, /* 256 */
+        { 320,   9,    9,  1,        0.6 ,    4.20, 25   ,  0,      1.00,         0,  0      ,       0}  /* 320 */
                                        };
 
     
@@ -97,6 +98,9 @@ int apply_abr_preset(lame_global_flags*  gfp, int preset, int enforce)
     if (abr_switch_map[r].safejoint > 0)
         lame_set_exp_nspsytune(gfp, lame_get_exp_nspsytune(gfp) | 2); /* safejoint */
 
+    if (abr_switch_map[r].sfscale > 0)
+        lame_set_sfscale(gfp, 1);
+
     /* ns-bass tweaks */
     if (abr_switch_map[r].nsbass != 0) {
         k = (int)(abr_switch_map[r].nsbass * 4);
@@ -184,8 +188,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 9);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(short_threshold_lrm, 4.50f, -1);
-            SET_OPTION(short_threshold_s, 30.0f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 1, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -203,8 +207,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         default: {
             SET_OPTION(vbr_smooth, 0, -1);
 
-            SET_OPTION(short_threshold_lrm, 4.50f, -1);
-            SET_OPTION(short_threshold_s, 30.0f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -225,8 +229,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 8);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(short_threshold_lrm, 4.50f, -1);
-            SET_OPTION(short_threshold_s, 30.0f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 1, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -244,8 +248,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         default: {
             SET_OPTION(vbr_smooth, 0, -1);
 
-            SET_OPTION(short_threshold_lrm, 4.50f, -1);
-            SET_OPTION(short_threshold_s, 30.0f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -266,8 +270,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 7);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(short_threshold_lrm, 4.50f, -1);
-            SET_OPTION(short_threshold_s, 30.0f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 1, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -285,8 +289,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         default: {
             SET_OPTION(vbr_smooth, 0, -1);
 
-            SET_OPTION(short_threshold_lrm, 4.50f, -1);
-            SET_OPTION(short_threshold_s, 30.0f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -307,8 +311,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 6);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(short_threshold_lrm, 4.45f, -1);
-            SET_OPTION(short_threshold_s, 27.5f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 1, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -326,8 +330,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         default: {
             SET_OPTION(vbr_smooth, 0, -1);
 
-            SET_OPTION(short_threshold_lrm, 4.45f, -1);
-            SET_OPTION(short_threshold_s, 27.5f, -1);
+            SET_OPTION(short_threshold_lrm, 6.20f, -1);
+            SET_OPTION(short_threshold_s, 45.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -348,8 +352,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 5);
         switch (lame_get_VBR(gfp)) {
             case vbr_rh: {
-            SET_OPTION(short_threshold_lrm, 4.40f, -1);
-            SET_OPTION(short_threshold_s, 25.0f, -1);
+            SET_OPTION(short_threshold_lrm, 5.90f, -1);
+            SET_OPTION(short_threshold_s, 40.0f, -1);
             SET_OPTION(quant_comp, 1, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -367,8 +371,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         default: {
             SET_OPTION(vbr_smooth, 0, -1);
 
-            SET_OPTION(short_threshold_lrm, 4.40f, -1);
-            SET_OPTION(short_threshold_s, 25.0f, -1);
+            SET_OPTION(short_threshold_lrm, 5.90f, -1);
+            SET_OPTION(short_threshold_s, 40.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -389,8 +393,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 4);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(short_threshold_lrm, 4.25f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 5.00f, -1);
+            SET_OPTION(short_threshold_s, 35.0f, -1);
             SET_OPTION(quant_comp, 3, -1);
             SET_OPTION(quant_comp_short, 3, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -409,8 +413,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         default: {
             SET_OPTION(vbr_smooth, 1, -1);
 
-            SET_OPTION(short_threshold_lrm, 4.25f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 5.00f, -1);
+            SET_OPTION(short_threshold_s, 35.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -432,8 +436,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 3);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(short_threshold_lrm, 3.75f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.70f, -1);
+            SET_OPTION(short_threshold_s, 30.0f, -1);
             SET_OPTION(quant_comp, 3, -1);
             SET_OPTION(quant_comp_short, 3, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -454,8 +458,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         default: {
             SET_OPTION(vbr_smooth, 1, -1);
 
-            SET_OPTION(short_threshold_lrm, 3.75f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.70f, -1);
+            SET_OPTION(short_threshold_s, 30.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -479,10 +483,10 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 2);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(VBR_min_bitrate_kbps, 96, 0); /*ideally, we should get rid of this*/
+            SET_OPTION(VBR_min_bitrate_kbps, 128, 0); /*ideally, we should get rid of this*/
 
-            SET_OPTION(short_threshold_lrm, 3.5f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.3f, -1);
+            SET_OPTION(short_threshold_s, 25.0f, -1);
             SET_OPTION(quant_comp, 3, -1);
             SET_OPTION(quant_comp_short, 3, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -498,11 +502,11 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
             return preset;
         }
         default: {
-            SET_OPTION(VBR_min_bitrate_kbps, 96, 0); /*ideally, we should get rid of this*/
+            SET_OPTION(VBR_min_bitrate_kbps, 128, 0); /*ideally, we should get rid of this*/
             SET_OPTION(vbr_smooth, 2, -1);
 
-            SET_OPTION(short_threshold_lrm, 3.5f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.3f, -1);
+            SET_OPTION(short_threshold_s, 25.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -523,10 +527,10 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         lame_set_VBR_q(gfp, 1);
         switch (lame_get_VBR(gfp)) {
         case vbr_rh: {
-            SET_OPTION(VBR_min_bitrate_kbps, 112, 0); /*ideally, we should get rid of this*/
+            SET_OPTION(VBR_min_bitrate_kbps, 128, 0); /*ideally, we should get rid of this*/
 
-            SET_OPTION(short_threshold_lrm, 3.3f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.2f, -1);
+            SET_OPTION(short_threshold_s, 25.0f, -1);
             SET_OPTION(quant_comp, 3, -1);
             SET_OPTION(quant_comp_short, 3, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -542,11 +546,11 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
             return preset;
         }
         default: {
-            SET_OPTION(VBR_min_bitrate_kbps, 112, 0);
+            SET_OPTION(VBR_min_bitrate_kbps, 128, 0);
             SET_OPTION(vbr_smooth, 2, -1);
 
-            SET_OPTION(short_threshold_lrm, 3.3f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.2f, -1);
+            SET_OPTION(short_threshold_s, 25.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -569,8 +573,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
         case vbr_rh: {
             SET_OPTION(VBR_min_bitrate_kbps, 128, 0);
 
-            SET_OPTION(short_threshold_lrm, 3.1f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.2f, -1);
+            SET_OPTION(short_threshold_s, 25.0f, -1);
             SET_OPTION(quant_comp, 3, -1);
             SET_OPTION(quant_comp_short, 3, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
@@ -589,8 +593,8 @@ int apply_preset(lame_global_flags*  gfp, int preset, int enforce)
             SET_OPTION(VBR_min_bitrate_kbps, 128, 0);
             SET_OPTION(vbr_smooth, 2, -1);
 
-            SET_OPTION(short_threshold_lrm, 3.1f, -1);
-            SET_OPTION(short_threshold_s, 15.0f, -1);
+            SET_OPTION(short_threshold_lrm, 4.2f, -1);
+            SET_OPTION(short_threshold_s, 25.0f, -1);
             SET_OPTION(quant_comp, 0, -1);
             SET_OPTION(quant_comp_short, 0, -1);
             SET_OPTION(psy_model, PSY_NSPSYTUNE, -1);
