@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: psymodel.c,v 1.135 2004/03/01 22:20:37 robert Exp $ */
+/* $Id: psymodel.c,v 1.135.2.2 2004/06/27 19:32:34 robert Exp $ */
 
 
 /*
@@ -1147,7 +1147,9 @@ static inline FLOAT8 NS_INTERP(FLOAT8 x, FLOAT8 y, FLOAT8 r)
 {
     /* was pow((x),(r))*pow((y),1-(r))*/
     if(r==1.0)
-        return x;              /* 99.7% of the time */ 
+        return x;              /* 99.7% of the time */
+    if(r==0.0)
+	return y;
     if(y>0.0)
         return pow(x/y,r)*y;   /* rest of the time */ 
     return 0.0;                /* never happens */ 
@@ -1304,7 +1306,7 @@ int L3psycho_anal_ns( lame_global_flags * gfp,
     FLOAT wsamp_S[2][3][BLKSIZE_s];
 
     /* block type  */
-    int blocktype[2],uselongblock[4];
+    int blocktype[2],uselongblock[2];
 
     /* usual variables like loop indices, etc..    */
     int numchn, chn;
@@ -1471,7 +1473,12 @@ int L3psycho_anal_ns( lame_global_flags * gfp,
 	    if (ns_attacks[2] && ns_attacks[1]) ns_attacks[2] = 0;
 	    if (ns_attacks[3] && ns_attacks[2]) ns_attacks[3] = 0;
 	}
-	uselongblock[chn] = ns_uselongblock;
+    if (chn < 2) {
+    	uselongblock[chn] = ns_uselongblock;
+    }
+    else if (ns_uselongblock == 0) {
+        uselongblock[0] = uselongblock[1] = 0;
+    }
 
 	/* there is a one granule delay.  Copy maskings computed last call
 	 * into masking_ratio to return to calling program.
