@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: quantize.c,v 1.147 2004/01/05 09:45:52 bouvigne Exp $ */
+/* $Id: quantize.c,v 1.151 2004/04/03 17:28:32 bouvigne Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -501,8 +501,9 @@ bin_search_StepSize(
  *
  ************************************************************************/
 static int
-float8compare(const FLOAT8 *a, const FLOAT8 *b)
+float8compare(const void * v1, const void * v2)
 {
+    const FLOAT8 *a = v1, *b = v2;
     if (*a > *b) return 1;
     if (*a == *b) return 0;
     return -1;
@@ -669,6 +670,27 @@ quant_compare(
 
     switch (quant_comp) {
         default:
+        case 9: {
+            /* minimize var_noise in order to shape noise */
+            if (best->over_count > 0 ) {
+                /* there are distorted sfb*/
+	            better = (calc->over_count == 0)
+                        || ( calc->over_noise <= best->over_noise &&
+                             calc->var_noise  <= best->var_noise )
+                        || ( calc->over_noise <= best->over_noise &&
+                             calc->max_noise  <= best->max_noise );
+            } else {
+                /* no distorted sfb*/
+                if (calc->over_count > 0) {
+                    better = 0;
+                } else {
+		            better = (calc->tot_noise < best->tot_noise)
+		                &&   (calc->var_noise <= best->var_noise);
+                }
+            }
+	        break;
+        }
+
         case 0:
 	    better = calc->over_count  < best->over_count
                ||  ( calc->over_count == best->over_count  &&
@@ -826,8 +848,11 @@ amp_scalefac_bands(
 		return;
 	}
 	cod_info->scalefac[sfb]++;
-	for (l = -width; l < 0; l++)
+    for (l = -width; l < 0; l++) {
 	    xrpow[j+l] *= ifqstep34;
+        if (xrpow[j+l] > cod_info->xrpow_max)
+            cod_info->xrpow_max = xrpow[j+l];
+    }
 
 	if (gfc->noise_shaping_amp==2)
 	    return;
@@ -861,8 +886,11 @@ inc_scalefac_scale (
 	j += width;
         if (s & 1) {
             s++;
-            for (l = -width; l < 0; l++) 
+            for (l = -width; l < 0; l++) {
                 xrpow[j+l] *= ifqstep34;
+                if (xrpow[j+l] > cod_info->xrpow_max)
+                    cod_info->xrpow_max = xrpow[j+l];
+            }
         }
         cod_info->scalefac[sfb] = s >> 1;
     }
@@ -898,17 +926,17 @@ inc_subblock_gain (
     }
 
     for (window = 0; window < 3; window++) {
-	int s1, s2, l, j;
+        int s1, s2, l, j;
         s1 = s2 = 0;
 
         for (sfb = cod_info->sfb_lmax+window;
-	     sfb < cod_info->sfbdivide; sfb += 3) {
+        sfb < cod_info->sfbdivide; sfb += 3) {
             if (s1 < scalefac[sfb])
-		s1 = scalefac[sfb];
+                s1 = scalefac[sfb];
         }
-	for (; sfb < cod_info->sfbmax; sfb += 3) {
-	    if (s2 < scalefac[sfb])
-		s2 = scalefac[sfb];
+        for (; sfb < cod_info->sfbmax; sfb += 3) {
+            if (s2 < scalefac[sfb])
+                s2 = scalefac[sfb];
         }
 
         if (s1 < 16 && s2 < 8)
@@ -918,37 +946,42 @@ inc_subblock_gain (
             return 1;
 
         /* even though there is no scalefactor for sfb12
-         * subblock gain affects upper frequencies too, that's why
-         * we have to go up to SBMAX_s
-         */
+        * subblock gain affects upper frequencies too, that's why
+        * we have to go up to SBMAX_s
+        */
         cod_info->subblock_gain[window]++;
-	j = gfc->scalefac_band.l[cod_info->sfb_lmax];
-	for (sfb = cod_info->sfb_lmax+window;
-	     sfb < cod_info->sfbmax; sfb += 3) {
-	    FLOAT8 amp;
-	    int width = cod_info->width[sfb], s = scalefac[sfb];
-	    assert(s >= 0);
-	    s = s - (4 >> cod_info->scalefac_scale);
+        j = gfc->scalefac_band.l[cod_info->sfb_lmax];
+        for (sfb = cod_info->sfb_lmax+window;
+        sfb < cod_info->sfbmax; sfb += 3) {
+            FLOAT8 amp;
+            int width = cod_info->width[sfb], s = scalefac[sfb];
+            assert(s >= 0);
+            s = s - (4 >> cod_info->scalefac_scale);
             if (s >= 0) {
-		scalefac[sfb] = s;
-		j += width*3;
-		continue;
-	    }
-
-	    scalefac[sfb] = 0;
-	    amp = IPOW20(210 + (s << (cod_info->scalefac_scale + 1)));
-	    j += width * (window+1);
-	    for (l = -width; l < 0; l++) {
-		xrpow[j+l] *= amp;
+                scalefac[sfb] = s;
+                j += width*3;
+                continue;
             }
-	    j += width*(3 - window - 1);
+
+            scalefac[sfb] = 0;
+            amp = IPOW20(210 + (s << (cod_info->scalefac_scale + 1)));
+            j += width * (window+1);
+            for (l = -width; l < 0; l++) {
+                xrpow[j+l] *= amp;
+                if (xrpow[j+l] > cod_info->xrpow_max)
+                    cod_info->xrpow_max = xrpow[j+l];
+            }
+            j += width*(3 - window - 1);
         }
 
-	{
-	    FLOAT8 amp = IPOW20(210 - 8);
-	    j += cod_info->width[sfb] * (window+1);
-	    for (l = -cod_info->width[sfb]; l < 0; l++)
-		xrpow[j+l] *= amp;
+        {
+            FLOAT8 amp = IPOW20(210 - 8);
+            j += cod_info->width[sfb] * (window+1);
+            for (l = -cod_info->width[sfb]; l < 0; l++) {
+                xrpow[j+l] *= amp;
+                if (xrpow[j+l] > cod_info->xrpow_max)
+                    cod_info->xrpow_max = xrpow[j+l];
+            }
         }
     }
     return 0;
