@@ -33,6 +33,7 @@
 #include "lame_global_flags.h"
 #include "lame-analysis.h"
 #include "id3tag.h"
+#include "gain_analysis.h"
 
 #if HAVE_INTTYPES_H
 # include <inttypes.h>
@@ -219,7 +220,6 @@ typedef struct
 } PSY_t; 
 
 
-
 #define MAX_CHANNELS  2
 
 typedef struct {
@@ -249,6 +249,9 @@ typedef struct {
 } resample_t;
 
 
+
+
+
 struct lame_internal_flags {
 
   /********************************************************************
@@ -494,14 +497,15 @@ struct lame_internal_flags {
   int nogap_total;
   int nogap_current;  
 
-  int findReplayGain;
   int RadioGain;
   int AudiophileGain;
 
-#ifdef DECODE_ON_THE_FLY
-  int decode_on_the_fly;
+  replaygain_t *rgdata;
+
+  int findPeakSample;
   sample_t PeakSample;
-#endif
+  int noclipGainChange;  /* gain change required for preventing clipping */
+  FLOAT noclipScale;     /* user-specified scale factor required for preventing clipping */
 
 #ifdef BRHIST
   /* simple statistics */
