@@ -1,4 +1,4 @@
-/* $Id: interface.c,v 1.44 2004/01/10 10:27:28 takehiro Exp $ */
+/* $Id: interface.c,v 1.46 2004/03/10 00:50:54 robert Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -245,6 +245,7 @@ int check_vbr_header(PMPSTR mp,int bytes)
 
     /*fprintf(stderr,"\rmpglib: delays: %i %i \n",mp->enc_delay,mp->enc_padding); */
     /* fprintf(stderr,"\rmpglib: Xing VBR header dectected.  MP3 file has %i frames\n", pTagData.frames); */
+    if ( pTagData.headersize < 1 ) return 1;
     return pTagData.headersize;
   }
   return 0;
@@ -342,12 +343,8 @@ int decodeMP3_clipchoice( PMPSTR mp,unsigned char *in,int isize,char *out,
 {
 	int i,iret,bits,bytes;
 
-	if(in) {
-		if(addbuf(mp,in,isize) == NULL) {
-			return MP3_ERR;
-		}
-	}
-
+	if (in && isize && addbuf(mp,in,isize) == NULL)
+	    return MP3_ERR;
 
 	/* First decode header */
 	if(!mp->header_parsed) {
