@@ -29,6 +29,11 @@ BOOL InitMP3(PMPSTR mp);
 int	 decodeMP3(PMPSTR mp,unsigned char *inmemory,int inmemsize,char *outmemory,int outmemsize,int *done);
 void ExitMP3(PMPSTR mp);
 
+/* added decodeMP3_unclipped to support returning raw floating-point values of samples. The representation
+   of the floating-point numbers is defined in mpg123.h as #define real. It is 64-bit double by default. 
+   No more than 1152 samples per channel are allowed. */
+int	 decodeMP3_unclipped(PMPSTR mp,unsigned char *inmemory,int inmemsize,char *outmemory,int outmemsize,int *done);
+
 /* added remove_buf to support mpglib seeking */
 void remove_buf(PMPSTR mp);
 
@@ -37,3 +42,4 @@ void remove_buf(PMPSTR mp);
 #endif
 
 #endif
+
